## 销售机构公募基金销售保有规模

接口：fund_sales_vol

描述：获取销售机构公募基金销售保有规模数据，本数据从2021年Q1开始公布，季度更新

限量：单次最大500行数据，目前总量只有100行，未来随着数据量增加会提高上限

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| year | str | N | 年度 |
| quarter | str | N | 季度 |
| name | str | N | 机构名称 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| year | int | Y | 年度 |
| quarter | str | Y | 季度 |
| inst_name | str | Y | 销售机构 |
| fund_scale | float | Y | 股票+混合公募基金保有规模（亿元） |
| scale | float | Y | 非货币市场公募基金保有规模（亿元） |
| rank | int | Y | 排名 |

接口示例

```python
pro = ts.pro_api()

df = pro.fund_sales_vol()
```

数据示例

```python
year quarter         inst_name           fund_scale   scale  rank
0   2021      Q1        招商银行股份有限公司    6711.00  7079.00     1
```

注：

1、股票+混合公募基金保有规模精确至0.01亿元进行排序。

2、表中所述“保有规模”包括各类投资者通过基金代销机构认申购公募基金（含交易所场内基金）及已参公规范的券商大集合产品形成的保有规模。